@@ -5,8 +5,7 @@ use crate::rule::{LintError, LintResult, LintWarning, Rule, RuleCategory, Severi
 use crate::rule_config_serde::RuleConfig;
 use crate::utils::document_structure::{DocumentStructure, DocumentStructureExtensions};
 use crate::utils::element_cache::{ElementCache, ListMarkerType};
-use lazy_static::lazy_static;
-use regex::Regex;
+use crate::utils::regex_cache::{CODE_FENCE_REGEX, UNORDERED_LIST_MARKER_REGEX};
 use toml;
 
 mod md007_config;
@@ -17,10 +16,6 @@ pub struct MD007ULIndent {
     config: MD007Config,
 }
 
-lazy_static! {
-    static ref LIST_ITEM_PATTERN: Regex = Regex::new(r"^(\s*)([*+-])(\s+)(.*)$").unwrap();
-}
-
 impl MD007ULIndent {
     pub fn new(indent: usize) -> Self {
         Self {
@@ -36,11 +31,48 @@ impl MD007ULIndent {
         Self { config }
     }
 
+    /// Get parent info for any list item to determine proper text alignment
+    /// Returns (has_parent, expected_indent_position)
+    fn get_parent_info(
+        &self,
+        ctx: &crate::lint_context::LintContext,
+        line_number: usize,
+        indentation: usize,
+    ) -> (bool, Option<usize>) {
+        // Look backward from current line to find parent item
+        for line_idx in (1..line_number).rev() {
+            if let Some(line_info) = ctx.line_info(line_idx) {
+                if let Some(list_item) = &line_info.list_item {
+                    // Found a list item - check if it's at a lower indentation (parent level)
+                    if list_item.marker_column < indentation {
+                        // This is a parent item - calculate where child content should align
+                        if list_item.is_ordered {
+                            // For ordered lists, calculate the position where text starts
+                            // e.g., "1. Text" -> text starts at position 3
+                            // e.g., "10. Text" -> text starts at position 4
+                            // e.g., "100. Text" -> text starts at position 5
+                            let text_start_pos = list_item.marker_column + list_item.marker.len() + 1; // +1 for space after marker
+                            return (true, Some(text_start_pos));
+                        } else {
+                            // For unordered lists, calculate where text starts
+                            // e.g., "  * Text" -> text starts at position 4 (2 spaces + "* ")
+                            let text_start_pos = list_item.marker_column + 2; // "* " or "- " or "+ "
+                            return (true, Some(text_start_pos));
+                        }
+                    }
+                }
+                // If we encounter non-blank, non-list content at column 0, stop looking
+                else if !line_info.is_blank && line_info.indent == 0 {
+                    break;
+                }
+            }
+        }
+        (false, None)
+    }
+
     #[allow(dead_code)]
     fn is_in_code_block(content: &str, line_idx: usize) -> bool {
-        lazy_static! {
-            static ref CODE_BLOCK_MARKER: Regex = Regex::new(r"^(```|~~~)").unwrap();
-        }
+        // Use centralized code fence pattern
 
         let lines: Vec<&str> = content.lines().collect();
         let mut in_code_block = false;
@@ -50,7 +82,7 @@ impl MD007ULIndent {
                 break;
             }
 
-            if CODE_BLOCK_MARKER.is_match(line.trim_start()) {
+            if CODE_FENCE_REGEX.is_match(line.trim_start()) {
                 in_code_block = !in_code_block;
             }
 
@@ -103,20 +135,36 @@ impl Rule for MD007ULIndent {
                 if !self.config.start_indented && item.nesting_level == 0 {
                     continue;
                 }
-                
+
                 let expected_indent = if self.config.start_indented {
                     self.config.start_indent + (item.nesting_level * self.config.indent)
                 } else {
-                    item.nesting_level * self.config.indent
+                    // For any nested item, check if it should align with parent's text content
+                    if item.nesting_level > 0 {
+                        let (has_parent, expected_pos) = self.get_parent_info(ctx, item.line_number, item.indentation);
+                        if has_parent {
+                            if let Some(pos) = expected_pos {
+                                // Align with parent's text content
+                                pos
+                            } else {
+                                // Fallback to standard indentation
+                                item.nesting_level * self.config.indent
+                            }
+                        } else {
+                            item.nesting_level * self.config.indent
+                        }
+                    } else {
+                        item.nesting_level * self.config.indent
+                    }
                 };
-                
+
                 if item.indentation != expected_indent {
                     // Generate fix for this list item
                     let fix = {
                         let lines: Vec<&str> = content.lines().collect();
                         if let Some(line) = lines.get(item.line_number - 1) {
                             // Extract the marker and content
-                            if LIST_ITEM_PATTERN.captures(line).is_some() {
+                            if UNORDERED_LIST_MARKER_REGEX.captures(line).is_some() {
                                 let correct_indent = " ".repeat(expected_indent);
 
                                 // Fix range should match warning range - only the problematic indentation
@@ -199,20 +247,36 @@ impl Rule for MD007ULIndent {
                 if !self.config.start_indented && item.nesting_level == 0 {
                     continue;
                 }
-                
+
                 let expected_indent = if self.config.start_indented {
                     self.config.start_indent + (item.nesting_level * self.config.indent)
                 } else {
-                    item.nesting_level * self.config.indent
+                    // For any nested item, check if it should align with parent's text content
+                    if item.nesting_level > 0 {
+                        let (has_parent, expected_pos) = self.get_parent_info(ctx, item.line_number, item.indentation);
+                        if has_parent {
+                            if let Some(pos) = expected_pos {
+                                // Align with parent's text content
+                                pos
+                            } else {
+                                // Fallback to standard indentation
+                                item.nesting_level * self.config.indent
+                            }
+                        } else {
+                            item.nesting_level * self.config.indent
+                        }
+                    } else {
+                        item.nesting_level * self.config.indent
+                    }
                 };
-                
+
                 if item.indentation != expected_indent {
                     // Generate fix for this list item
                     let fix = {
                         let lines: Vec<&str> = content.lines().collect();
                         if let Some(line) = lines.get(item.line_number - 1) {
                             // Extract the marker and content
-                            if LIST_ITEM_PATTERN.captures(line).is_some() {
+                            if UNORDERED_LIST_MARKER_REGEX.captures(line).is_some() {
                                 let correct_indent = " ".repeat(expected_indent);
 
                                 // Fix range should match warning range - only the problematic indentation
@@ -294,9 +358,11 @@ impl Rule for MD007ULIndent {
     /// Check if this rule should be skipped
     fn should_skip(&self, ctx: &crate::lint_context::LintContext) -> bool {
         // Skip if content is empty or has no unordered list items
-        ctx.content.is_empty() || !ctx.lines.iter().any(|line| {
-            line.list_item.as_ref().map_or(false, |item| !item.is_ordered)
-        })
+        ctx.content.is_empty()
+            || !ctx
+                .lines
+                .iter()
+                .any(|line| line.list_item.as_ref().is_some_and(|item| !item.is_ordered))
     }
 
     fn as_any(&self) -> &dyn std::any::Any {
@@ -392,7 +458,10 @@ mod tests {
         let content = "* Item 1\n   * Item 2\n      * Item 3";
         let ctx = LintContext::new(content);
         let result = rule.fix(&ctx).unwrap();
-        let expected = "* Item 1\n  * Item 2\n    * Item 3";
+        // With dynamic alignment:
+        // Item 2 aligns with Item 1's text (2 spaces)
+        // Item 3 aligns with Item 2's text (4 + 1 = 5 spaces)
+        let expected = "* Item 1\n  * Item 2\n     * Item 3";
         assert_eq!(result, expected);
     }
 
@@ -548,36 +617,40 @@ repos:
 
     #[test]
     fn test_custom_indent_3_spaces() {
+        // Test dynamic alignment behavior (default start_indented=false)
         let rule = MD007ULIndent::new(3);
+
         let content = "* Item 1\n   * Item 2\n      * Item 3";
         let ctx = LintContext::new(content);
         let result = rule.check(&ctx).unwrap();
-        assert!(result.is_empty());
+        // With dynamic alignment, Item 2 should align with Item 1's text (2 spaces)
+        // and Item 3 should align with Item 2's text (4 spaces), not fixed increments
+        assert!(!result.is_empty()); // Should have warnings due to alignment
 
-        // Test that 2-space indentation fails with 3-space config
-        let wrong_content = "* Item 1\n  * Item 2";
-        let ctx = LintContext::new(wrong_content);
+        // Test that dynamic alignment works correctly
+        // Item 3 should align with Item 2's text content (4 spaces)
+        let correct_content = "* Item 1\n  * Item 2\n    * Item 3";
+        let ctx = LintContext::new(correct_content);
         let result = rule.check(&ctx).unwrap();
-        assert_eq!(result.len(), 1);
-
-        // Test fix
-        let fixed = rule.fix(&ctx).unwrap();
-        assert_eq!(fixed, "* Item 1\n   * Item 2");
+        assert!(result.is_empty());
     }
 
     #[test]
     fn test_custom_indent_4_spaces() {
+        // Test dynamic alignment behavior (default start_indented=false)
         let rule = MD007ULIndent::new(4);
         let content = "* Item 1\n    * Item 2\n        * Item 3";
         let ctx = LintContext::new(content);
         let result = rule.check(&ctx).unwrap();
-        assert!(result.is_empty());
+        // With dynamic alignment, should expect 2 spaces and 6 spaces, not 4 and 8
+        assert!(!result.is_empty()); // Should have warnings due to alignment
 
-        // Test fix with wrong indentation
-        let wrong_content = "* Item 1\n  * Item 2\n    * Item 3";
-        let ctx = LintContext::new(wrong_content);
-        let fixed = rule.fix(&ctx).unwrap();
-        assert_eq!(fixed, "* Item 1\n    * Item 2\n        * Item 3");
+        // Test correct dynamic alignment
+        // Item 3 should align with Item 2's text content (4 spaces)
+        let correct_content = "* Item 1\n  * Item 2\n    * Item 3";
+        let ctx = LintContext::new(correct_content);
+        let result = rule.check(&ctx).unwrap();
+        assert!(result.is_empty());
     }
 
     #[test]
@@ -598,12 +671,14 @@ repos:
         let content_multi = "* Item 1\n\t* Item 2\n\t\t* Item 3";
         let ctx = LintContext::new(content_multi);
         let fixed = rule.fix(&ctx).unwrap();
-        assert_eq!(fixed, "* Item 1\n  * Item 2\n    * Item 3");
+        // With dynamic alignment: Item 3 aligns with Item 2 at correct position
+        assert_eq!(fixed, "* Item 1\n  * Item 2\n   * Item 3");
 
         // Mixed tabs and spaces
         let content_mixed = "* Item 1\n \t* Item 2\n\t * Item 3";
         let ctx = LintContext::new(content_mixed);
         let fixed = rule.fix(&ctx).unwrap();
+        // With dynamic alignment: Item 3 aligns with Item 2 at correct position
         assert_eq!(fixed, "* Item 1\n  * Item 2\n    * Item 3");
     }
 
@@ -612,8 +687,9 @@ repos:
         let rule = MD007ULIndent::default();
 
         // MD007 only checks unordered lists, so ordered lists should be ignored
+        // Note: 3 spaces is now correct for bullets under ordered items
         let content = r#"1. Ordered item
-   * Unordered sub-item (wrong indent)
+   * Unordered sub-item (correct - 3 spaces under ordered)
    2. Ordered sub-item
 * Unordered item
   1. Ordered sub-item
@@ -621,18 +697,11 @@ repos:
 
         let ctx = LintContext::new(content);
         let result = rule.check(&ctx).unwrap();
-        assert_eq!(result.len(), 1, "Only unordered list indentation should be checked");
-        assert_eq!(result[0].line, 2, "Error should be on line 2");
+        assert_eq!(result.len(), 0, "All unordered list indentation should be correct");
 
-        // Fix should only correct unordered lists
+        // No fix needed as all indentation is correct
         let fixed = rule.fix(&ctx).unwrap();
-        let expected = r#"1. Ordered item
-  * Unordered sub-item (wrong indent)
-   2. Ordered sub-item
-* Unordered item
-  1. Ordered sub-item
-  * Unordered sub-item"#;
-        assert_eq!(fixed, expected);
+        assert_eq!(fixed, content);
     }
 
     #[test]
@@ -714,16 +783,18 @@ tags:
         let content = "* Item 1 with **bold** and *italic*\n   * Item 2 with `code`\n     * Item 3 with [link](url)";
         let ctx = LintContext::new(content);
         let fixed = rule.fix(&ctx).unwrap();
-        let expected = "* Item 1 with **bold** and *italic*\n  * Item 2 with `code`\n    * Item 3 with [link](url)";
+        // With dynamic alignment: Item 3 aligns with Item 2's text (2 + 2 + 1 = 5 spaces)
+        let expected = "* Item 1 with **bold** and *italic*\n  * Item 2 with `code`\n     * Item 3 with [link](url)";
         assert_eq!(fixed, expected, "Fix should only change indentation, not content");
     }
 
     #[test]
     fn test_start_indented_config() {
-        let mut config = MD007Config::default();
-        config.start_indented = true;
-        config.start_indent = 4;
-        config.indent = 2;
+        let config = MD007Config {
+            start_indented: true,
+            start_indent: 4,
+            indent: 2,
+        };
         let rule = MD007ULIndent::from_config_struct(config);
 
         // First level should be indented by start_indent (4 spaces)
@@ -753,18 +824,24 @@ tags:
     #[test]
     fn test_start_indented_false_allows_any_first_level() {
         let rule = MD007ULIndent::default(); // start_indented is false by default
-        
+
         // When start_indented is false, first level items at any indentation are allowed
         let content = "   * Item 1"; // First level at 3 spaces
         let ctx = LintContext::new(content);
         let result = rule.check(&ctx).unwrap();
-        assert!(result.is_empty(), "First level at any indentation should be allowed when start_indented is false");
-        
+        assert!(
+            result.is_empty(),
+            "First level at any indentation should be allowed when start_indented is false"
+        );
+
         // Multiple first level items at different indentations should all be allowed
         let content = "* Item 1\n  * Item 2\n    * Item 3"; // All at level 0 (different indents)
         let ctx = LintContext::new(content);
         let result = rule.check(&ctx).unwrap();
-        assert!(result.is_empty(), "All first-level items should be allowed at any indentation");
+        assert!(
+            result.is_empty(),
+            "All first-level items should be allowed at any indentation"
+        );
     }
 
     #[test]
@@ -791,4 +868,60 @@ tags:
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 2, "Deep nesting errors should be detected");
     }
+
+    #[test]
+    fn test_bullets_nested_under_numbered_items() {
+        let rule = MD007ULIndent::default();
+        let content = "\
+1. **Active Directory/LDAP**
+   - User authentication and directory services
+   - LDAP for user information and validation
+
+2. **Oracle Unified Directory (OUD)**
+   - Extended user directory services";
+        let ctx = LintContext::new(content);
+        let result = rule.check(&ctx).unwrap();
+        // Should have no warnings - 3 spaces is correct for bullets under numbered items
+        assert!(
+            result.is_empty(),
+            "Expected no warnings for bullets with 3 spaces under numbered items, got: {result:?}"
+        );
+    }
+
+    #[test]
+    fn test_bullets_nested_under_numbered_items_wrong_indent() {
+        let rule = MD007ULIndent::default();
+        let content = "\
+1. **Active Directory/LDAP**
+  - Wrong: only 2 spaces";
+        let ctx = LintContext::new(content);
+        let result = rule.check(&ctx).unwrap();
+        // Should flag incorrect indentation
+        assert_eq!(
+            result.len(),
+            1,
+            "Expected warning for incorrect indentation under numbered items"
+        );
+        assert!(
+            result
+                .iter()
+                .any(|w| w.line == 2 && w.message.contains("Expected 3 spaces"))
+        );
+    }
+
+    #[test]
+    fn test_regular_bullet_nesting_still_works() {
+        let rule = MD007ULIndent::default();
+        let content = "\
+* Top level
+  * Nested bullet (2 spaces is correct)
+    * Deeply nested (4 spaces)";
+        let ctx = LintContext::new(content);
+        let result = rule.check(&ctx).unwrap();
+        // Should have no warnings - standard bullet nesting still uses 2-space increments
+        assert!(
+            result.is_empty(),
+            "Expected no warnings for standard bullet nesting, got: {result:?}"
+        );
+    }
 }
