@@ -141,7 +141,8 @@ fn test_fix_adjacent_to_markdown() {
     let content = "*markdown* _markdown_ `markdown` [markdown](link)";
     let ctx = rumdl::lint_context::LintContext::new(content);
     let fixed = rule.fix(&ctx).unwrap();
-    assert_eq!(fixed, "*Markdown* _Markdown_ `Markdown` [Markdown](link)");
+    // When code_blocks=true, inline code should not be fixed
+    assert_eq!(fixed, "*Markdown* _Markdown_ `markdown` [Markdown](link)");
 }
 
 #[test]
